@@ -335,8 +335,12 @@
 #pragma mark - VLCLocalServerDiscoveryController
 - (void)discoveryFoundSomethingNew
 {
+    NSString * (^mapServiceName)(id<VLCLocalNetworkService>) = ^NSString *(id<VLCLocalNetworkService> service) {
+        return [NSString stringWithFormat:@"%@: %@", service.serviceName, service.title];
+    };
 
     NSMutableArray<id<VLCLocalNetworkService>> *newNetworkServices = [NSMutableArray array];
+    NSMutableSet<NSString *> *addedNetworkServices = [[NSMutableSet alloc] init];
     VLCLocalServerDiscoveryController *discoveryController = self.discoveryController;
     NSUInteger sectionCount = [discoveryController numberOfSections];
     for (NSUInteger section = 0; section < sectionCount; ++section) {
@@ -345,7 +349,11 @@
             NSIndexPath *indexPath = [NSIndexPath indexPathForItem:index inSection:section];
             id<VLCLocalNetworkService> service = [discoveryController networkServiceForIndexPath:indexPath];
             if (service != nil) {
-                [newNetworkServices addObject:service];
+                NSString *mappedName = mapServiceName(service);
+                if(![addedNetworkServices containsObject:mappedName]) {
+                    [addedNetworkServices addObject:mappedName];
+                    [newNetworkServices addObject:service];
+                }
             }
         }
     }
@@ -353,9 +361,7 @@
     NSArray *oldNetworkServices = self.networkServices;
     GRKArrayDiff *diff = [[GRKArrayDiff alloc] initWithPreviousArray:oldNetworkServices
                                                         currentArray:newNetworkServices
-                                                       identityBlock:^NSString * _Nullable(id <VLCLocalNetworkService> service) {
-                                                           return [NSString stringWithFormat:@"%@: %@", service.serviceName, service.title];
-                                                       }
+                                                       identityBlock:mapServiceName
                                                        modifiedBlock:nil];
 
     [diff performBatchUpdatesWithCollectionView:self.collectionView
